---
name: Bug Report
about: Create a bug report to help us improve jobflow
title: "BUG:"
---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

Provide any example files that are needed to reproduce the error,
especially if the bug pertains to parsing of a file.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.
